pub struct WebGPUBindGroup(pub BindGroupId);Tuple Fields
0: BindGroupIdTrait Implementations
Sourceimpl Clone for WebGPUBindGroup
impl Clone for WebGPUBindGroup
Sourcefn clone(&self) -> WebGPUBindGroup
fn clone(&self) -> WebGPUBindGroup
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WebGPUBindGroup
Sourceimpl Debug for WebGPUBindGroup
impl Debug for WebGPUBindGroup
Sourceimpl<'de> Deserialize<'de> for WebGPUBindGroup
impl<'de> Deserialize<'de> for WebGPUBindGroup
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WebGPUBindGroup
Sourceimpl Hash for WebGPUBindGroup
impl Hash for WebGPUBindGroup
Sourceimpl MallocSizeOf for WebGPUBindGroup
impl MallocSizeOf for WebGPUBindGroup
Sourcefn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for WebGPUBindGroup
impl PartialEq for WebGPUBindGroup
Sourcefn eq(&self, other: &WebGPUBindGroup) -> bool
fn eq(&self, other: &WebGPUBindGroup) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WebGPUBindGroup
impl PartialOrd for WebGPUBindGroup
Sourceimpl Serialize for WebGPUBindGroup
impl Serialize for WebGPUBindGroup
impl StructuralPartialEq for WebGPUBindGroup