pub struct WebGPUBindGroupLayout(pub BindGroupLayoutId);Tuple Fields
0: BindGroupLayoutIdTrait Implementations
Sourceimpl Clone for WebGPUBindGroupLayout
impl Clone for WebGPUBindGroupLayout
Sourcefn clone(&self) -> WebGPUBindGroupLayout
fn clone(&self) -> WebGPUBindGroupLayout
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WebGPUBindGroupLayout
Sourceimpl Debug for WebGPUBindGroupLayout
impl Debug for WebGPUBindGroupLayout
Sourceimpl<'de> Deserialize<'de> for WebGPUBindGroupLayout
impl<'de> Deserialize<'de> for WebGPUBindGroupLayout
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WebGPUBindGroupLayout
Sourceimpl Hash for WebGPUBindGroupLayout
impl Hash for WebGPUBindGroupLayout
Sourceimpl MallocSizeOf for WebGPUBindGroupLayout
impl MallocSizeOf for WebGPUBindGroupLayout
Sourcefn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for WebGPUBindGroupLayout
impl PartialEq for WebGPUBindGroupLayout
Sourcefn eq(&self, other: &WebGPUBindGroupLayout) -> bool
fn eq(&self, other: &WebGPUBindGroupLayout) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WebGPUBindGroupLayout
impl PartialOrd for WebGPUBindGroupLayout
Sourceimpl Serialize for WebGPUBindGroupLayout
impl Serialize for WebGPUBindGroupLayout
impl StructuralPartialEq for WebGPUBindGroupLayout