pub struct WebGPUContextId(pub u64);Tuple Fields
0: u64Trait Implementations
Sourceimpl Clone for WebGPUContextId
impl Clone for WebGPUContextId
Sourcefn clone(&self) -> WebGPUContextId
fn clone(&self) -> WebGPUContextId
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WebGPUContextId
Sourceimpl Debug for WebGPUContextId
impl Debug for WebGPUContextId
Sourceimpl<'de> Deserialize<'de> for WebGPUContextId
impl<'de> Deserialize<'de> for WebGPUContextId
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WebGPUContextId
Sourceimpl Hash for WebGPUContextId
impl Hash for WebGPUContextId
Sourceimpl MallocSizeOf for WebGPUContextId
impl MallocSizeOf for WebGPUContextId
Sourcefn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for WebGPUContextId
impl PartialEq for WebGPUContextId
Sourcefn eq(&self, other: &WebGPUContextId) -> bool
fn eq(&self, other: &WebGPUContextId) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WebGPUContextId
impl PartialOrd for WebGPUContextId
Sourceimpl Serialize for WebGPUContextId
impl Serialize for WebGPUContextId
impl StructuralPartialEq for WebGPUContextId