pub struct WebGPUSampler(pub SamplerId);Tuple Fields
0: SamplerIdTrait Implementations
Sourceimpl Clone for WebGPUSampler
impl Clone for WebGPUSampler
Sourcefn clone(&self) -> WebGPUSampler
fn clone(&self) -> WebGPUSampler
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WebGPUSampler
Sourceimpl Debug for WebGPUSampler
impl Debug for WebGPUSampler
Sourceimpl<'de> Deserialize<'de> for WebGPUSampler
impl<'de> Deserialize<'de> for WebGPUSampler
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WebGPUSampler
Sourceimpl Hash for WebGPUSampler
impl Hash for WebGPUSampler
Sourceimpl MallocSizeOf for WebGPUSampler
impl MallocSizeOf for WebGPUSampler
Sourcefn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for WebGPUSampler
impl PartialEq for WebGPUSampler
Sourcefn eq(&self, other: &WebGPUSampler) -> bool
fn eq(&self, other: &WebGPUSampler) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WebGPUSampler
impl PartialOrd for WebGPUSampler
Sourceimpl Serialize for WebGPUSampler
impl Serialize for WebGPUSampler
impl StructuralPartialEq for WebGPUSampler