pub struct WebGPUSurface(pub SurfaceId);Tuple Fields
0: SurfaceIdTrait Implementations
Sourceimpl Clone for WebGPUSurface
impl Clone for WebGPUSurface
Sourcefn clone(&self) -> WebGPUSurface
fn clone(&self) -> WebGPUSurface
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for WebGPUSurface
Sourceimpl Debug for WebGPUSurface
impl Debug for WebGPUSurface
Sourceimpl<'de> Deserialize<'de> for WebGPUSurface
impl<'de> Deserialize<'de> for WebGPUSurface
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for WebGPUSurface
Sourceimpl Hash for WebGPUSurface
impl Hash for WebGPUSurface
Sourceimpl MallocSizeOf for WebGPUSurface
impl MallocSizeOf for WebGPUSurface
Sourcefn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
fn size_of(&self, _ops: &mut MallocSizeOfOps) -> usize
Measure the heap usage of all descendant heap-allocated structures, but
not the space taken up by the value itself.
Sourceimpl PartialEq for WebGPUSurface
impl PartialEq for WebGPUSurface
Sourcefn eq(&self, other: &WebGPUSurface) -> bool
fn eq(&self, other: &WebGPUSurface) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl PartialOrd for WebGPUSurface
impl PartialOrd for WebGPUSurface
Sourceimpl Serialize for WebGPUSurface
impl Serialize for WebGPUSurface
impl StructuralPartialEq for WebGPUSurface